window.Gleam.initSearch([{"doc":"gliberapay","title":"gliberapay","content":"# gliberapay\n\nWork with Liberapay in Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/gliberapay)](https://hex.pm/packages/gliberapay)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gliberapay/)\n\n```sh\ngleam add gliberapay\n```\n```gleam\nimport gliberapay\nimport httpc\n\npub fn main() {\n  // Download a CSV of Liberapay patrons for a recipient\n  let req = gliberapay.download_patrons_csv_request(&quot;gleam&quot;)\n  let assert Ok(resp) = httpc.send(req)\n\n  // Parse the CSV\n  let assert Ok(patrons) = gliberapay.parse_patrons_csv(resp.body)\n  patrons\n}\n```\nThis returns data like this:\n```gleam\n[\n  Patron(\n    pledge_date: Date(2024, 3, 12),\n    patron_id: 1_847_734,\n    patron_username: &quot;erikareads&quot;,\n    patron_public_name: Some(&quot;erikareads&quot;),\n    donation_currency: &quot;USD&quot;,\n    weekly_amount: None,\n    patron_avatar_url: &quot;https://seccdn.libravatar.org/avatar/3beb6ba272afe47c05f19288b480cbcb?s=160&amp;d=404&quot;,\n  ),\n  Patron(\n    pledge_date: Date(2024, 3, 15),\n    patron_id: 1_847_917,\n    patron_username: &quot;~1847917&quot;,\n    patron_public_name: None,\n    donation_currency: &quot;CHF&quot;,\n    weekly_amount: Some(4.8),\n    patron_avatar_url: &quot;https://seccdn.libravatar.org/avatar/0837ca2eb9199aa134c4b2fc9ce382a2?s=160&amp;d=404&quot;,\n  ),\n]\n```\n  \n\nFurther documentation can be found at &lt;https://hexdocs.pm/gliberapay&gt;.\n","url":"index.html"},{"doc":"gliberapay","title":"Date","content":"pub type Date {\n  Date(year: Int, month: Int, day: Int)\n}\n\nDate(year: Int, month: Int, day: Int)\n\n\nSynonyms:\ngliberapay.Date\ngliberapay Date","url":"gliberapay.html#Date"},{"doc":"gliberapay","title":"Error","content":"pub type Error {\n  InvalidCsvSyntax(String)\n  MissingCsvHeaderRow\n  MissingCsvHeaders(missing: List(String))\n  InvalidValue(detail: String)\n}\n\nInvalidCsvSyntax(String)\n\n\nMissingCsvHeaderRow\n\n\nMissingCsvHeaders(missing: List(String))\n\n\nInvalidValue(detail: String)\n\n\nSynonyms:\ngliberapay.Error\ngliberapay Error","url":"gliberapay.html#Error"},{"doc":"gliberapay","title":"Patron","content":"pub type Patron {\n  Patron(\n    pledge_date: Date,\n    patron_id: Int,\n    patron_username: String,\n    patron_public_name: Option(String),\n    donation_currency: String,\n    weekly_amount: Option(Float),\n    patron_avatar_url: String,\n  )\n}\n\nPatron(\n  pledge_date: Date,\n  patron_id: Int,\n  patron_username: String,\n  patron_public_name: Option(String),\n  donation_currency: String,\n  weekly_amount: Option(Float),\n  patron_avatar_url: String,\n)\n\npatron_public_name\n&lt;p&gt;The name the patron has chosen to display publicly.&lt;/p&gt;\n&lt;p&gt;If the patron has not set a public name then this will be &lt;code&gt;None&lt;/code&gt; and you\nmay want to use &lt;code&gt;patron_username&lt;/code&gt; instead.&lt;/p&gt;\n\nweekly_amount\n&lt;p&gt;The amount the patron has pledged to donate per week.&lt;/p&gt;\n&lt;p&gt;If the patron has set their amount to be private then this will be &lt;code&gt;None&lt;/code&gt;.&lt;/p&gt;\n\nSynonyms:\ngliberapay.Patron\ngliberapay Patron","url":"gliberapay.html#Patron"},{"doc":"gliberapay","title":"download_patrons_csv_request","content":"pub fn download_patrons_csv_request(\n  recipient recipient: String,\n) -&gt; Request(String)\n Construct a HTTP request to download the public Liberapay patrons CSV for\n the given recipient.\n\n Once you have a response for the request you can parse the body with the\n `parse_patrons_csv` function.\n\nSynonyms:\ngliberapay.download_patrons_csv_request\ngliberapay download_patrons_csv_request","url":"gliberapay.html#download_patrons_csv_request"},{"doc":"gliberapay","title":"parse_patrons_csv","content":"pub fn parse_patrons_csv(\n  csv: String,\n) -&gt; Result(List(Patron), Error)\n Parse a Liberapay patrons CSV, as can be downloaded from the Liberapay, e.g.\n &lt;https://liberapay.com/gleam/patrons/public.csv&gt;\n\n If you want to download this in Gleam see the `download_patrons_csv` function.\n\nSynonyms:\ngliberapay.parse_patrons_csv\ngliberapay parse_patrons_csv","url":"gliberapay.html#parse_patrons_csv"},{"doc":"gliberapay","title":"gliberapay","content":"","url":"gliberapay.html"}]);